Learn R Programming

palmid (version 0.0.3)

get.tax: get.tax

Description

Retrieve the taxonomic identifiers for a set of 'palm_id' for a given rank.

Usage

get.tax(palm_ids, con, rank = "family", ordinal = FALSE)

Arguments

palm_ids

character, set of 'palm_id' to lookup in palmdb

con

pq-connection, use SerratusConnect()

rank

character, taxonomic rank to retrieve. One of "species", "genus", "family" (Default), "phylum"

ordinal

boolean, return an ordered vector based on input 'palm_ids'

Value

character, unique 'tax_id' vector (i.e. "Coronaviridae")

Examples

Run this code
# NOT RUN {
con <- SerratusConnect()

# Return species-identifiers for a set of palmprints (uxxx)
get.tax(c("u2", "u1337"), con, rank = "species")

# }

Run the code above in your browser using DataLab