powered by
Retrieve the taxonomic identifiers for a set of 'palm_id' for a given rank.
get.tax(palm_ids, con, rank = "family", ordinal = FALSE)
character, set of 'palm_id' to lookup in palmdb
pq-connection, use SerratusConnect()
character, taxonomic rank to retrieve. One of "species", "genus", "family" (Default), "phylum"
boolean, return an ordered vector based on input 'palm_ids'
character, unique 'tax_id' vector (i.e. "Coronaviridae")
# NOT RUN { con <- SerratusConnect() # Return species-identifiers for a set of palmprints (uxxx) get.tax(c("u2", "u1337"), con, rank = "species") # }
Run the code above in your browser using DataLab